==> ideaIC-15.0.3-sources.jar: com/intellij/codeInspection/dataFlow/instructions/CheckReturnValueInstruction.java <==
/*
 * Copyright 2000-2009 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.codeInspection.dataFlow.instructions;

import com.intellij.codeInspection.dataFlow.DataFlowRunner;
import com.intellij.codeInspection.dataFlow.DfaInstructionState;
import com.intellij.codeInspection.dataFlow.DfaMemoryState;
import com.intellij.codeInspection.dataFlow.InstructionVisitor;
import com.intellij.psi.PsiElement;

/**
 * @author max
 */
public class CheckReturnValueInstruction extends Instruction {
  private final PsiElement myReturnValue;

  public CheckReturnValueInstruction(final PsiElement returnValue) {
    myReturnValue = returnValue;
  }

  @Override
  public DfaInstructionState[] accept(DataFlowRunner runner, DfaMemoryState stateBefore, InstructionVisitor visitor) {
    return visitor.visitCheckReturnValue(this, runner, stateBefore);
  }

  public PsiElement getReturn() {
    return myReturnValue;
  }

  public String toString() {
    return "CheckReturnValue";
  }
}

==> ideaIC-182.4323.18-sources.jar: com/intellij/codeInspection/dataFlow/instructions/CheckReturnValueInstruction.java <==
/*
 * Copyright 2000-2009 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.codeInspection.dataFlow.instructions;

import com.intellij.codeInspection.dataFlow.DataFlowRunner;
import com.intellij.codeInspection.dataFlow.DfaInstructionState;
import com.intellij.codeInspection.dataFlow.DfaMemoryState;
import com.intellij.codeInspection.dataFlow.InstructionVisitor;
import com.intellij.psi.PsiExpression;
import org.jetbrains.annotations.NotNull;

/**
 * @author max
 */
public class CheckReturnValueInstruction extends Instruction {
  private final @NotNull PsiExpression myReturnValue;

  public CheckReturnValueInstruction(@NotNull PsiExpression returnValue) {
    myReturnValue = returnValue;
  }

  @Override
  public DfaInstructionState[] accept(DataFlowRunner runner, DfaMemoryState stateBefore, InstructionVisitor visitor) {
    return visitor.visitCheckReturnValue(this, runner, stateBefore);
  }

  @NotNull
  public PsiExpression getReturn() {
    return myReturnValue;
  }

  public String toString() {
    return "CheckReturnValue";
  }
}
